MapModelResults class

Constructors

MapModelResults({String? formattedAddress, MapModelResultsGeometry? geometry, String? name, int? rating, int? userRatingsTotal})
MapModelResults.fromJson(Map<String, dynamic> json)

Properties

formattedAddress ↔ String?
getter/setter pair
geometry ↔ MapModelResultsGeometry?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
rating ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userRatingsTotal ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited