GoogleMapsPickPlace class

Inheritance

Constructors

GoogleMapsPickPlace({required String apiKey, Language mapLanguage = Language.arabic, dynamic getResult(FullAddress)?, LatLng initialPosition = const LatLng(29.9773, 31.1325), bool enableMyLocationButton = true, bool enableSearchButton = true, Widget loader = const Center(child: CircularProgressIndicator(strokeWidth: 2.0)), Widget? doneButton, Widget? errorButton, double zoomFactor = 5.0, MarkerColor markerColor = MarkerColor.red, Key? key})
const

Properties

apiKey → String
Key for Google Maps API
final
doneButton → Widget?
Widget to show when the map is done loading and apply getResult method
final
enableMyLocationButton → bool
Enable or disable the My Location button
final
enableSearchButton → bool
Enable or disable the Search button
final
errorButton → Widget?
Widget to show when there's a corruption or there's no internet connection
final
getResult → dynamic Function(FullAddress)?
Method to get the position of the place on the map
final
hashCode → int
The hash code for this object.
no setterinherited
initialPosition → LatLng
Initial position of the map in case there's no location and GPS is off
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loader → Widget
Widget to show while the map is loading
final
mapLanguage → Language
searchLanguage is the property of GoogleMapsPickPlace that controls search results language.
final
markerColor → MarkerColor
Marker color of the map (default is red)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoomFactor → double
Zoom factor of the map (default is 5.0)
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<GoogleMapsPickPlace>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited