MapWidget class

Inheritance

Constructors

MapWidget({required Marker marker, required void onMapCreated(GoogleMapController)?, required dynamic getLocation(LatLng), double zoomFactor = 5.0, required LatLng initialPosition, Key? key})
MapWidget which showing the map and let the user pick the place from it
const

Properties

getLocation → dynamic Function(LatLng)
Method which getting the location
final
hashCode → int
The hash code for this object.
no setterinherited
initialPosition → LatLng
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
marker → Marker
Marker which represents the place picked
final
onMapCreated → void Function(GoogleMapController)?
Method which initializing google map controller
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoomFactor → double
Zoom Factor which controls the map's zoom
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited